
# Titulo de la Sintaxis: 
# Master de tabulados 

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

# Se usa la funcion p_load() desde el paquete pacman, el cual instala  
# el paquete si esta ausente, y carga para el uso si ya esta instalado 

# Se asegura que el paquete "pacman" este instalado
if(!require("pacman")) install.packages("pacman") 

# Paquetes disponibles desde CRAN

pacman::p_load(
  
  # Gestion de proyectos y archivos 
  here,     # construye rutas a los archivos de su proyecto 
  rio,      # importacion / exportacion de varios tipos de datos
  openxlsx, # importacion / exportacion de libros de Excel de varias hojas
  
  # Instalacion y manejo de paquetes 
  pacman, # instalar y cargar paquetes 
  
  # Manejo general de los datos 
  Hmisc, # funciones utiles para el analsis de datos 
  expss, # tablas, etiquetas y funciones de hojas de calculo y estadisticas de 'SPSS'
  tidyverse, # incluye paquetes para ordenar y presentar los datos 
  lubridate, # trabaja con fechas 
  pillar,    # herramientas para manejar columnas de datos
  janitor,   # Limpieza de datos y tablas
  sjlabelled, # para tratar etiquetas 
  epikit, # agregar categorias
  
  # Estadisticas
  summarytools, # herramientas para resumir datos de forma rapida y ordenada
  
  # Manejo de muestras complejas 
  srvyr,  # estadistica de resumen para datos de encuentas 
  
  # Paquetes para calculos especificos 
  anthro # calculo de puntuaciones z de antropometria infantil
  
)

# Limpieza del espacio de trabajo 
rm(list = ls(all = TRUE))

#==============================================================================#
####                         Uso de los scripts                             ####
#==============================================================================#

# Los scripts de indicadores fueron elaborados segun tematicas y con numeracion 
# segun el orden establecido en los tabulados. 

# Para cada scritp existe uno con su mismo nombre pero finalizado con "_excel", 
# estos scripts sirven para exportar los resultados de los indicadores en 
# formato excel. 

# El primer script que se debe correr para generar el archivo excel con las
# repectivas hojas de calculo es "00_indice_excel.R", ya que los demas scripts
# cargan el archivo para imprimir los resultados en el mismo. 

# Para la ejecucion del presente script, el cual ejecuta los scripts de 
# exportacion y estos a su vez los scripts de calculo de indicadores, se
# recomienda que la ruta de los archivos se encuentre correctamente establecida. 

#==============================================================================#
####                             Tabulados                                  ####
#==============================================================================#

# Ubicar las direcciones en donde se encuentras los scripts de exportacion 
# Ej: source("C:/ENDI/Scripts/Indicadores/00_indice_excel_publi.R", encoding = "UTF-8") 

# Indice
source("/00_indice_excel.R", encoding = "UTF-8")

# Vivienda y hogar 
source("/01_vivienda_hogar_excel.R", encoding = "UTF-8")

# Hacinamiento 
source("/02_hacinamiento_excel.R", encoding = "UTF-8")

# Estado Nutricional - antropometria
source("/03_estado_nutricional_excel.R", encoding = "UTF-8")

# Estado nutricional - hemoglobina
source("/04_anemia_excel.R", encoding = "UTF-8")

# Vacunacion 
source("/05_vacunacion_excel.R", encoding = "UTF-8")

# Lactancia 
source("/06_lactancia_excel.R", encoding = "UTF-8")

# Control prenatal 
source("/07_control_prenatal_excel.R", encoding = "UTF-8")

# Salud en la ninez 
source("/08_salud_ninez_excel.R", encoding = "UTF-8")

# Primera infancia 
source("/09_primera_infancia_excel.R", encoding = "UTF-8")

# Fecundidad 
source("/10_fecundidad_excel.R", encoding = "UTF-8")

# Fecundidad 
source("/11_fecundidad_excel.R", encoding = "UTF-8")

# Calidad de agua 
source("/12_calidad_agua_excel.R", encoding = "UTF-8")

# Abrir archivo sin guardar 
# openXL(wb)

# Apartado para guadar resultados 
# Ej: saveWorkbook(wb, "Exports/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)

saveWorkbook(wb, "/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)
