
# Titulo de la Sintaxis: 
# Exportacion de resultados  

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 	 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

if(!require("pacman")) install.packages("pacman") 

pacman::p_load(
  openxlsx # importacion / exportacion de libros de Excel de varias hojas
)

#==============================================================================#
####                              Funciones                                 ####
#==============================================================================#

# Titulos   
Style_titulos <- function(yy,zz) {
  
  # En Indice 
  # Agregar hojas
  addWorksheet(wb, sheetName = "INDICE", gridLines = FALSE)
  
  # Insertar imagen
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             "INDICE", 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 31.75, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Titulo   
  setRowHeights(wb,
                sheet = "INDICE",
                rows = 1,
                heights = 70)
  
  tabSty <- createStyle(fontSize = 15.7,
                        fontName = "Century Gothic",
                        fontColour = "#595959",
                        textDecoration = "bold",
                        halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = 3,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  setColWidths(wb, 
               sheet  = "INDICE", 
               cols   = "B", 
               widths = 147
  )
  
  setColWidths(wb, 
               sheet  = "INDICE", 
               cols   = "A", 
               widths = 5
  ) 
  
  writeData(wb,
            sheet       = "INDICE",
            x           = yy,
            xy          = c("B", 3)
  )
  
  # Subtitulo
  tabSty <- createStyle(fontSize = 14.7,
                        fontName = "Century Gothic",
                        fontColour = "#595959",
                        textDecoration = "bold",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = 5,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           = zz,
            xy          = c("B", 5)
  )
  
}

# Subtitulos
Style_subtitulos <- function(y,z,xz,yy) {
  
  headSty <- createStyle(fontSize = 12,
                         fontName = "Century Gothic",
                         fontColour = "#363636",
                         fgFill = "#836FFF",
                         halign = "center",
                         valign = "center",
                         textDecoration = "bold")
  
  addStyle(wb,
           sheet      = y,
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet = y,
            x = z,
            xy = c("A",yy)
  )
  
  tabSty <- createStyle(fontSize = 12,
                        fontName = "Century Gothic",
                        fontColour = "#363636",
                        fgFill = "#836FFF",
                        halign = "left",
                        valign = "center",
                        textDecoration = "bold")
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = y, 
            x           =  xz,
            xy          = c("B", yy)
  )
  
} 

# Indicador 
Style_indicador <- function(y,xz,yy,zz,x) {
  
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 33.25, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:", "Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,
                                          "Nacional / Área / Región Natural / Provincia / Parroquias / Sexo / Auto-Identificación Étnica / Quintil / Pobreza por ingresos / Pobreza por NBI", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 2:6,
           cols       = 2,  
           gridExpand = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 2:6,
           cols       = 3,  
           gridExpand = TRUE
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 61),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 61,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 61:68,
             cols = 2:11
  )
  
} 

# Indicador
Style_indicadorm <- function(y,xz,yy,zz,x) {
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 29.75, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:", "Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,
                                          "Nacional / Área / Región Natural / Provincia / Parroquias / Auto-Identificación Étnica / Quintiles / Pobreza por NBI", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 2:6,
           cols       = 2,  
           gridExpand = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 2:6,
           cols       = 3,  
           gridExpand = TRUE
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 59),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 59,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 59:63,
             cols = 2:11
  )
} 

# Indicador
Style_indicadorm_n <- function(y,xz,yy,zz,x) {
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 33.25, 
  #             height = 29.75,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:", "Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,
                                          "Nacional / Área / Región Natural / Provincia / Parroquias / Sexo / Auto-Identificación Étnica / Quintiles / Pobreza por NBI", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 2:6,
           cols       = 2,  
           gridExpand = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 2:6,
           cols       = 3,  
           gridExpand = TRUE
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 61),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 61,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 61:65,
             cols = 2:11
  )
} 

# Indicador
Style_indicadorh <- function(y,xz,yy,zz,x) {
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 33.25, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:", "Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,
                                          "Nacional / Área / Región Natural / Provincia / Parroquias / Quintil / Pobreza por ingresos / Pobreza por NBI ", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 2:6,
           cols       = 2,  
           gridExpand = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 2:6,
           cols       = 3,  
           gridExpand = TRUE
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 53),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 53,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 53:57,
             cols = 2:11
  )
} 

# Indicador freq
Style_indicador_f <- function(y,xz,yy,zz,x) {
  
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 33.25, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:", "Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,
                                          "Nacional / Área", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 2:6,
           cols       = 2,  
           gridExpand = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 2:6,
           cols       = 3,  
           gridExpand = TRUE
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 25),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 25,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 25:29,
             cols = 2:11
  )
  
} 

# Indicador agua
Style_indicador_a <- function(y,xz,yy,zz,x) {
  
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center"
                         )
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 33, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:","","Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,"",
                                          "Nacional / Área / Región Natural / Provincia / Parroquias / Quintil / Pobreza por ingresos / Pobreza por NBI", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 3:4,
             cols = 3:10
  )
  mergeCells(wb,
             sheet = y,
             cols = 2,
             rows = 3:4
  )
  
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        valign = "top",
                        textDecoration = "bold",
                        wrapText = TRUE
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left",
                         valign = "top",
                         wrapText = TRUE
  )
  
  tabSty2 <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        textDecoration = "bold"
  )
  
  tabSty3 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )

  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 3:4,
           cols       = "B",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 3:4,
           cols       = "C",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty2,
           rows       = c(1,2,5,6,7),
           cols       = "B",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty3,
           rows       = c(1,2,5,6,7),
           cols       = "C",  
           gridExpand = TRUE
  )
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <-  data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 54),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 54,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 54:58,
             cols = 2:11
  )
  
} 

# Indicador agua_freq
Style_indicador_a_f <- function(y,xz,yy,zz,x) {
  
  headSty <- createStyle(fontSize = 11,
                         fontName = "Century Gothic",
                         halign = "center"
  )
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = headSty,
           rows       = yy,
           cols       = "A", 
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               "INDICE",
               startRow = yy,
               startCol = 1,
               x = makeHyperlinkString(
                 sheet = y, row = 1, col = 1,
                 text = y
               )
  )
  
  tabSty <- createStyle(fontSize = 11,
                        fontName = "Century Gothic",
                        halign = "left")
  
  addStyle(wb,
           sheet      = "INDICE",
           style      = tabSty,
           rows       = yy,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = "INDICE", 
            x           =  xz,
            xy          = c("B", yy)
  )
  
  # Agregar hojas
  addWorksheet(wb, sheetName = y, gridLines = FALSE)
  
  # Insertar imagen
  
  # setRowHeights(wb,
  #               sheet = y,
  #               rows = 1,
  #               heights = 70
  # )
  # Ingresar la ruta en donde se encuente la imagen 
  # Ej: 
  # img <- file.path("Info","Imagen","endi_imagen.png")
  
  # insertImage(wb, 
  #             y, 
  #             img, 
  #             startRow = 1, 
  #             startCol = "B", 
  #             width = 31, 
  #             height = 2.30,
  #             units = "cm"
  # )
  
  # Identificacion de la tabla
  setColWidths(wb, 
               sheet  = y, 
               cols   = "A", 
               widths = 1.25
  )
  
  df_eti <- data.frame(Etiqueta = c("Tabla N°:", "Indicador/variable:","","Población:",
                                    "Fuente:", "Elaboración:"),
                       Especificacion = c(zz, xz,"",
                                          "Nacional / Área", 
                                          "Encuesta Nacional sobre Desnutrición Infantil - ENDI 2022 -2023",
                                          "Instituto Nacional de Estadística y Censos (INEC)"))
  
  writeData(wb,
            sheet       = y, 
            x           = df_eti,
            xy          = c("B", 2),
            colNames    = FALSE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 3:4,
             cols = 3:10
  )
  mergeCells(wb,
             sheet = y,
             cols = 2,
             rows = 3:4
  )
  tabSty <- createStyle(fontSize = 10.5,
                        fontName = "Century Gothic",
                        halign = "left",
                        valign =  "top",
                        textDecoration = "bold",
                        wrapText = TRUE
  )
  
  tabSty1 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left",
                         valign = "top",
                         wrapText = TRUE
  )
  
  tabSty2 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left",
                         textDecoration = "bold"
  )
  
  tabSty3 <- createStyle(fontSize = 10.5,
                         fontName = "Century Gothic",
                         halign = "left"
  )
  
  addStyle(wb,
           sheet      = y,
           style      = tabSty,
           rows       = 3:4,
           cols       = "B",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty1,
           rows       = 3:4,
           cols       = "C",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty2,
           rows       = c(1,2,5,6,7),
           cols       = "B",  
           gridExpand = TRUE
  )
  addStyle(wb,
           sheet      = y,
           style      = tabSty3,
           rows       = c(1,2,5,6,7),
           cols       = "C",  
           gridExpand = TRUE
  )
  setColWidths(wb,
               sheet  = y,
               cols   = "B",
               widths = 16.5
  )
  
  setColWidths(wb,
               sheet  = y,
               cols   = "C",
               widths = 24.25
  )
  
  nota <- data.frame(Especificacion = ifelse(nchar(x) > 0, x, ""))
  
  writeData(wb,
            sheet       = y, 
            x           = nota,
            xy          = c("B", 26),
            colNames    = FALSE
  )
  notaStyle <- createStyle(fontSize = 9,
                           fontName = "Century Gothic",
                           halign = "left",
                           valign = "top",
                           wrapText = TRUE
  )
  
  addStyle(wb,
           sheet      = y,
           style      = notaStyle,
           rows       = 26,
           cols       = 2,
           gridExpand = TRUE
  )
  
  mergeCells(wb,
             sheet = y,
             rows = 26:30,
             cols = 2:11
  )
  
} 

#==============================================================================#
####                              Exportacion                               ####
#==============================================================================#

# Crear un libro de trabajo 
wb  <- createWorkbook()
modifyBaseFont(wb, fontSize = 12, fontName = "Calibri")

# Aplicacion de funciones -----------------------------------------------------#  

Style_titulos("ENCUESTA NACIONAL DE DESNUTRICIÓN INFANTIL - ENDI 2022 - 2023", "Indicadores")

Style_subtitulos("INDICE","T1","Datos de la vivienda y el hogar", "6")
Style_indicadorh("T1_i1","Porcentaje de hogares con niñas/os menores de 5 años sin adecuado sistema de eliminacion de excretas","7",1,"Nota: Hogares sin adecuado sistema de eliminación de excretas son aquellos que cuentan con estos tipos de servicio higiénico: inodoro o escusado conectado a pozo 
            séptico, conectado a biodigestor, conectado a pozo ciego, con descarga directa al mar, río, lago o quebrada, letrina o no tiene.")
Style_indicadorh("T1_i2","Porcentaje de hogares con niñas/os menores de 5 que utiliza suministros seguros de agua para beber","8",2, "Nota: Los componentes que pemiten establecer si un hogar utiliza suministros seguros de agua para beber son: tipo de suministro, tratamiento que da al agua antes de 
            beberla, cercanía del suministro y suficiencia de agua para beber.")
Style_indicadorh("T1_i3","Porcentaje de hogares con niñas/os menores de 5 años con hacinamiento","9",3,"Nota: El hacinamiento se relaciona con la cantidad de personas en comparación con el número de dormitorios disponibles. Se considera que hay hacinamiento cuando esta 
            relación es mayor a tres, o cuando no existe ningún dormitorio exclusivo para dormir.")

Style_subtitulos("INDICE","T2","Estado nutricional", "10")
Style_indicador("T2_i1","Prevalencia de desnutrición crónica en niñas/os menores de 2 años","11",4,"Nota: Denutrición crónica es el retardo en talla para la edad en niñas/os menores de 2 años.")
Style_indicador("T2_i2","Prevalencia de desnutrición global en niñas/os menores de 2 años","12",5,"Nota: Denutrición global es el peso bajo para la edad en niñas/os menores de 2 años.")
Style_indicador("T2_i3","Prevalencia de desnutrición aguda en niñas/os menores de 2 años","13",6,"Nota: Denutrición aguda es cuando el puntaje z del indicador peso para la talla está por debajo de menos dos y por encima de menos tres desviaciones 
            estándar y puede acompañarse de delgadez en niñas/os menores de 2 años.")
Style_indicador("T2_i4","Prevalencia de desnutrición crónica en niñas/os menores de 5 años","14",7,"Nota: Denutrición crónica es el retardo en talla para la edad en niñas/os menores de 5 años.")
Style_indicador("T2_i5","Prevalencia de desnutrición global en niñas/os menores de 5 años","15",8,"Nota: Denutrición global es el peso bajo para la edad en niñas/os menores de 5 años.")
Style_indicador("T2_i6","Prevalencia de desnutrición aguda en niñas/os menores de 5 años","16",9,"Nota: Denutrición aguda es cuando el puntaje z del indicador peso para la talla está por debajo de menos dos y por encima de menos tres desviaciones 
            estándar y puede acompañarse de delgadez en niñas/os menores de 5 años.")
Style_indicador("T2_i7","Prevalencia de desnutrición crónica en niñas/os de 2 años a menores de 5 años","17",10,"Nota: Denutrición crónica es el retardo en talla para la edad en niñas/os de 2 años a menores de 5 años.")
Style_indicador("T2_i8","Prevalencia de desnutrición global en niñas/os de 2 años a menores de 5 años","18",11,"Nota: Denutrición global es el peso bajo para la edad en niñas/os de 2 años a menores de 5 años.")
Style_indicador("T2_i9","Prevalencia de desnutrición aguda en niñas/os de 2 años a menores de 5 años","19",12,"Nota: Denutrición aguda es cuando el puntaje z del indicador peso para la talla está por debajo de menos dos y por encima de menos tres desviaciones 
            estándar y puede acompañarse de delgadez en niñas/os de 2 años a menores de 5 años.")
Style_indicador("T2_i10","Prevalencia de sobrepeso en niñas/os menores de 5 años","20",13,"Nota: El sobrepeso es el índice de masa corporal (IMC) para la edad con más de una desviación estándar por encima de la mediana establecida en los patrones de 
            crecimiento infantil de la OMS en niñas/os menores de 5 años.")
Style_indicador("T2_i11","Prevalencia de obesidad en niñas/os menores de 5 años","21",14,"Nota: La obesidad es mayor que dos desviaciones estándar por encima de la mediana establecida en los patrones de crecimiento infantil de la OMS en niñas/os menores de 5 
            años.")
Style_indicador("T2_i12","Prevalencia de sobrepeso y obesidad en niñas/os menores de 5 años","22",15,"Nota: El sobrepeso y la obesidad se definen como una acumulación anormal o excesiva de grasa que puede ser perjudicial para la salud, en niñas/os menores de 5 años.")
Style_indicador("T2_i13","Prevalencia de malnutrición en niñas/os menores de 5 años","23",16,"Nota: Malnutrición se basa en una alimentación desequilibrada, ya sea por exceso o por la escasez de diversos componentes o nutrientes que el organismo necesita, 
            como las vitaminas, los minerales u otros en niñas/os menores de 5 años.")
Style_indicador("T2_i14","Prevalencia doble carga de malnutrición en niñas/os menores de 5 años","24",17,"Nota: La doble carga de la malnutrición, es cuando se presenta el sobrepeso y la obesidad en coexistencia con elevadas tasas de retardo en talla en 
            niñas/os menores de 5 años.")
Style_indicador("T2_i15","Prevalencia de anemia en niñas/os de 6 a 59 meses de edad","25",18,"")
Style_indicador_f("T2_i16","Tipo de anemia en niñas/os de 6 a 59 meses de edad","26",19,"Nota: La OMS establece los cortes de concentración de hemoglobina para definir la anemia a escala poblacional y su gravedad:
            Anemia grave: Menos de 7,
            Anemia moderada: De 7 a 9.9,
            Anemia leve: De 10 a 10.9")
Style_indicador("T2_i17","Prevalencia de anemia en madres con niñas/os menores de 5 años","27",20,"")

Style_subtitulos("INDICE","T3","Vacunación", "28")
Style_indicador("T3_i1","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con BCG antes de cumplir el primer año","29",21,"")
Style_indicador("T3_i2","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con hepatitis B antes de cumplir el primer año","30",22,"")
Style_indicador("T3_i3","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con las dos dosis de rotavirus antes de cumplir el primer año","31",23,"")
Style_indicador("T3_i4","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con las tres dosis de pentavalente antes de cumplir el primer año","32",24,"")
Style_indicador("T3_i5","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con las tres dosis de antipoliomielítica antes de cumplir el primer año","33",25,"")
Style_indicador("T3_i6","Porcentaje de niñas/os de 12 a 59 meses que fueron vacunados con las tres dosis de neumococo antes de cumplir el primer año","34",26,"")

Style_subtitulos("INDICE","T4","Lactancia materna", "35")
Style_indicador("T4_i1","Porcentaje de niñas/os menores de 1 año con inicio temprano de la lactancia materna","36",27,"")
Style_indicador("T4_i2","Porcentaje de niñas/os menores de 2 años con inicio temprano de la lactancia materna","37",28,"")
Style_indicador("T4_i3","Porcentaje de niñas/os menores de 6 meses con lactancia materna exclusiva","38",29,"")
Style_indicador("T4_i4","Porcentaje de niñas/os de 12 a 15 meses con lactancia materna continua","39",30,"")
Style_indicador("T4_i5","Porcentaje de niñas/os de 6 a 23 meses de edad que recibieron alimentos de cuatro y más grupos alimentarios durante el día anterior","40",31,"Nota: Los grupos alimentarios que se elaboran para el cálculo de este indicador son:
            Grupo 1: cereales, raíces y tubérculos,
            Grupo 2: legumbres y nueces,
            Grupo 3: lácteos (leche, yogurt, queso),
            Grupo 4: carnes (carne, pescado, aves e hígado o carnes provenientes de visceras),
            Grupo 5: huevos,
            Grupo 6: frutas y verduras ricas en vitamina A,
            Grupo 7: otras frutas y verduras.")

Style_subtitulos("INDICE","T5","Controles prenatales", "41")
Style_indicadorm_n("T5_i1","Promedio de controles prenatales durante el embarazo de madres con niñas/os menores de 2 años","42",32,"")
Style_indicador("T5_i2","Porcentaje de niñas/os menores de 2 años cuyas madres recibieron al menos 5 controles prenatales durante el embarazo","43",33,"")
Style_indicador("T5_i3","Porcentaje de niñas/os menores de 2 años cuyas madres consumieron hierro y ácido fólico durante el embarazo","44",34,"")
Style_indicador("T5_i4","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de VIH antes de la semana 20 de embarazo","45",35,"")
Style_indicador("T5_i5","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de VIH a partir de la semana 20 de embarazo","46",36,"")
Style_indicador("T5_i6","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de VIH durante el embarazo","47",37,"")
Style_indicador("T5_i7","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de orina antes de la semana 20 de embarazo","48",38,"")
Style_indicador("T5_i8","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de orina a partir de la semana 20 de embarazo","49",39,"")
Style_indicador("T5_i9","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de orina durante el embarazo","50",40,"")
Style_indicador("T5_i10","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de TORCHs antes de la semana 20 de embarazo","51",41,"")
Style_indicador("T5_i11","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de TORCHs a partir de la semana 20 de embarazo","52",42,"")
Style_indicador("T5_i12","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de TORCHs durante el embarazo","53",43,"")
Style_indicador("T5_i13","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron al menos un examen de VIH, orina y TORCHs durante el embarazo","54",44,"")
Style_indicador("T5_i14","Porcentaje de niñas/os menores de 2 años cuyas madres recibieron la vacuna del tétanos y difteria durante el embarazo","55",45,"")
Style_indicador("T5_i15","Porcentaje de niñas/os menores de 2 años cuyas madres se realizaron ecos obstétricos durante el embarazo","56",46,"")
Style_indicadorm_n("T5_i16","Promedio de controles prenatales durante el embarazo de madres con niñas/os menores de 5 años","57",47,"")
Style_indicador("T5_i17","Porcentaje de niñas/os menores de 5 años cuyas madres recibieron al menos 5 controles prenatales durante el embarazo","58",48,"")
Style_indicador("T5_i18","Porcentaje de niñas/os menores de 5 años cuyas madres consumieron hierro y ácido fólico durante el embarazo","59",49,"")
Style_indicador("T5_i19","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de VIH antes de la semana 20 de embarazo","60",50,"")
Style_indicador("T5_i20","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de VIH a partir de la semana 20 de embarazo","61",51,"")
Style_indicador("T5_i21","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de VIH durante el embarazo","62",52,"")
Style_indicador("T5_i22","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de orina antes de la semana 20 de embarazo","63",53,"")
Style_indicador("T5_i23","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de orina a partir de la semana 20 de embarazo","64",54,"")
Style_indicador("T5_i24","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de orina durante el embarazo","65",55,"")
Style_indicador("T5_i25","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de TORCHs antes de la semana 20 de embarazo","66",56,"")
Style_indicador("T5_i26","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de TORCHs a partir de la semana 20 de embarazo","67",57,"")
Style_indicador("T5_i27","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de TORCHs durante el embarazo","68",58,"")
Style_indicador("T5_i28","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron al menos un examen de VIH, orina y TORCHs durante el embarazo","69",59,"")
Style_indicador("T5_i29","Porcentaje de niñas/os menores de 5 años cuyas madres recibieron la vacuna del tétanos y difteria durante el embarazo","70",60,"")
Style_indicador("T5_i30","Porcentaje de niñas/os menores de 5 años cuyas madres se realizaron ecos obstétricos durante el embarazo","71",61,"")

Style_subtitulos("INDICE","T6","Salud en la niñez", "72")
Style_indicadorm_n("T6_i1","Promedio de consejerías de lactancia materna exclusiva que recibieron las madres con niñas/os menores de 6 meses","73",62,"")
Style_indicador("T6_i2","Porcentaje de niñas/os menores de 5 años con bajo peso al nacer","74",63,"")
Style_indicador("T6_i3","Porcentaje de niñas/os menores de 5 años con inscripción de nacidos vivos en el Registro Civil","75",64,"")
Style_indicador("T6_i4","Porcentaje de niñas/os de 24 a 59 meses que tuvieron al menos 13 controles de niño sano","76",65,"")
Style_indicador("T6_i5","Porcentaje de niñas/os menores de 5 años con enfermedad diarreica aguda (EDA)","77",66,"")
Style_indicador("T6_i6","Porcentaje de niñas/os menores de 5 años con infección respiratoria aguda (IRA)","78",67,"")
Style_indicador("T6_i7","Porcentaje de niñas/os de 6 a 24 meses que consumieron hierro","79",68,"")

Style_subtitulos("INDICE","T7","Programas de primera infancia", "80")
Style_indicador("T7_i1","Porcentaje de niñas/os menores de 5 años que asisten o participan al Centro de Desarrollo Infantil (CDI) o centro de educación inicial","81",69,"")
Style_indicador("T7_i2","Porcentaje de niñas/os menores de 3 años que reciben atención por parte de educadoras del programa Creciendo con Nuestros Hijos (CNH)","82",70,"")

Style_subtitulos("INDICE","T8","Características de fecundidad de las madres", "83")
Style_indicadorm("T8_i1","Edad promedio de las madres al momento del nacimiento de su primer hijo","84",71,"Nota: Las mujeres contempladas en este indicador tienen al menos una niña/o menores de 5 años.")
Style_indicadorm("T8_i2","Promedio de espaciamiento en meses entre nacimientos de las hijas/os de las madres","85",72,"Nota: Las mujeres contempladas en este indicador tienen al menos una niña/o menores de 5 años.")
Style_indicador("T8_i3","Porcentaje de niñas/os menores de 5 años concebidos a través de un embarazo deseado y planeado","86",73,"")
Style_indicador("T8_i4","Porcentaje de niñas/os menores de 5 años concebidos a través de un embarazo deseado y no previsto","87",74,"")
Style_indicador("T8_i5","Porcentaje de niñas/os menores de 5 años concebidos a través de un embarazo no deseado y no previsto","88",75,"")
Style_indicador("T8_i6","Porcentaje de niñas/os menores de 5 años que nacieron en establecimientos de salud","89",76,"")
Style_indicador("T8_i7","Porcentaje de niñas/os menores de 5 años que su nacimiento fue atendido por personal de salud calificado","90",77,"")
Style_indicador("T8_i8","Porcentaje de niñas/os menores de 5 años cuyas madres tuvieron su parto por cesárea","91",78,"")
Style_indicador("T8_i9","Porcentaje de mujeres con niñas/os menores de 5 años que recibieron control post parto antes de los siete días","92",79,"")

Style_subtitulos("INDICE","T9","Calidad del agua", "93")
Style_indicador_a("T9_i1","Porcentaje de hogares con niñas/os menores de 5 años sin presencia de cloro residual en el agua para beber tomada desde la fuente o suministro","94",80,"Nota: La muestra de la fuente se determinará con base en las respuestas proporcionadas por el hogar y se recoge la muestra directamente con una funda esterilizada.
            El cloro, en general, es el desinfectante más económico y más común. Desde el punto de vista de la salud, es un producto bactericida y virucida eficaz en la mayoría de        
            las situaciones. El cloro residual presente en el agua desinfectada también ayuda a proteger el sistema de distribución contra la recontaminación microbiana, impide el       
            crecimiento bacteriano.")
Style_indicador_a("T9_i2","Porcentaje de hogares con niñas/os menores de 5 años sin presencia de cloro residual en el agua para beber tomada del punto de consumo","95",81,"Nota: La muestra del punto de consumo es el recipiente en el que el informante vierte el agua proveniente de la fuente, para su consumo.
            El cloro, en general, es el desinfectante más económico y más común. Desde el punto de vista de la salud, es un producto bactericida y virucida eficaz en la mayoría de 
            las situaciones. El cloro residual presente en el agua desinfectada también ayuda a proteger el sistema de distribución contra la recontaminación microbiana, impide el 
            crecimiento bacteriano.")
Style_indicador_a("T9_i3","Porcentaje de hogares con niñas/os menores de 5 años con presencia de la bacteria E-coli en el agua para beber tomada desde la fuente o suministro","96",82,"Nota: La muestra de la fuente se determinará con base en las respuestas proporcionadas por el hogar y se recoge la muestra directamente con una funda esterilizada.
            La bacteria E-coli es una bacteria que se encuentra normalmente en el intestino del ser humano y de los animales de sangre caliente, se transmite principalmente por el
            consumo de alimentos contaminados, como productos de carne picada cruda o poco cocida y leche cruda. La contaminación fecal del agua y de otros alimentos, así 
            como la contaminación cruzada durante la preparación de estos.")
Style_indicador_a("T9_i4","Porcentaje de hogares con niñas/os menores de 5 años con presencia de la bacteria E-coli en el agua para beber tomada del punto de consumo","97",83,"Nota: La muestra del punto de consumo es el recipiente en el que el informante vierte el agua proveniente de la fuente, para su consumo.
            La bacteria E-coli es una bacteria que se encuentra normalmente en el intestino del ser humano y de los animales de sangre caliente, se transmite principalmente por el 
            consumo de alimentos contaminados, como productos de carne picada cruda o poco cocida y leche cruda. La contaminación fecal del agua y de otros alimentos, así 
            como la contaminación cruzada durante la preparación de estos.")
Style_indicador_a_f("T9_i5","Porcentaje de hogares con niñas/os menores de 5 años por clasificación de cloro residual en el agua para beber tomada desde la fuente o suministro","98",84,"Nota: La muestra de la fuente se determinará con base en las respuestas proporcionadas por el hogar y se recoge la muestra directamente con una funda esterilizada.
            El cloro, en general, es el desinfectante más económico y más común. Desde el punto de vista de la salud, es un producto bactericida y virucida eficaz en la mayoría de 
            las situaciones. El cloro residual presente en el agua desinfectada también ayuda a proteger el sistema de distribución contra la recontaminación microbiana, impide el
            crecimiento bacteriano.")
Style_indicador_a_f("T9_i6","Porcentaje de hogares con niñas/os menores de 5 años por clasificación de cloro residual en el agua para beber tomada del punto de consumo","99",85,"Nota: La muestra del punto de consumo es el recipiente en el que el informante vierte el agua proveniente de la fuente, para su consumo.
            El cloro, en general, es el desinfectante más económico y más común. Desde el punto de vista de la salud, es un producto bactericida y virucida eficaz en la mayoría de 
            las situaciones. El cloro residual presente en el agua desinfectada también ayuda a proteger el sistema de distribución contra la recontaminación microbiana, impide el 
            crecimiento bacteriano.")
Style_indicador_a_f("T9_i7","Porcentaje de hogares con niñas/os menores de 5 años por clasificación de riesgo de presencia de la bacteria E-coli en el agua para beber tomada desde la fuente o suministro","100",86,"Nota: La muestra de la fuente se determinará con base en las respuestas proporcionadas por el hogar y se recoge la muestra directamente con una funda esterilizada.
            La bacteria E-coli es una bacteria que se encuentra normalmente en el intestino del ser humano y de los animales de sangre caliente, se transmite principalmente por el 
            consumo de alimentos contaminados, como productos de carne picada cruda o poco cocida y leche cruda. La contaminación fecal del agua y de otros alimentos, así 
            como la contaminación cruzada durante la preparación de estos.")
Style_indicador_a_f("T9_i8","Porcentaje de hogares con niñas/os menores de 5 años por clasificación de riesgo de presencia de la bacteria E-coli en el agua para beber tomada del punto de consumo","101",87,"Nota: La muestra del punto de consumo es el recipiente en el que el informante vierte el agua proveniente de la fuente, para su consumo.
            La bacteria E-coli es una bacteria que se encuentra normalmente en el intestino del ser humano y de los animales de sangre caliente, se transmite principalmente por el 
            consumo de alimentos contaminados, como productos de carne picada cruda o poco cocida y leche cruda. La contaminación fecal del agua y de otros alimentos, así 
            como la contaminación cruzada durante la preparación de estos.")

#------------------------------------------------------------------------------#

# Abrir archivo sin guardar 
# openXL(wb)

# Apartado para guadar resultados 
# Ej: saveWorkbook(wb, "Exports/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)

saveWorkbook(wb, "/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)
