
# Titulo de la Sintaxis: 
# Exportacion de datos de Estado nutricional a partir de indicadores 
# antropometricos

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

if(!require("pacman")) install.packages("pacman") 
pacman::p_load(here,
               grid, # Para graficas
               ggforce) # Para graficas

#==============================================================================#
####                          Ejecucion de script                           ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion source 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# source("C:/ENDI/Scripts/Indicadores/03_estado_nutricional.R")

source("/03_estado_nutricional.R")

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Funcion para agregar tablas descriptivas dependiendo los diferentes tipos de 
# desagregacion  

tab_fun <- function(design, x, by_1, by_2, by_3, by_4, by_5, 
                    by_6, by_7, by_8, by_9) {  
  
  # Nacional 
  tab_nac <- design %>% 
    srvyr_prop(.data[[x]])
  
  # Area 
  tab_area <- design %>% 
    srvyr_prop_by(.data[[x]], {{ by_1 }}) 
  
  # Region
  tab_reg <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_2 }})
  
  # Provincia
  tab_prov <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_3 }})
  
  # Parroquias priorizadas  
  tab_parr <- design %>%
    filter(!is.na({{ by_4 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_4 }}) 
  
  # Sexo
  tab_sex <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_5 }})
  
  # Auto-Identificacion etnica
  tab_etnia <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_6 }})
  
  # Quintiles
  tab_quintil <- design %>%
    filter(!is.na({{ by_7 }})) %>% 
    srvyr_prop_by(.data[[x]], {{ by_7 }})
  
  # Pobreza por Ingresos  
  tab_pobreza <- design %>%
    filter(!is.na({{ by_8 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_8 }}) 
  
  # Pobreza por NBI  
  tab_pobreza_nbi <- design %>%
    filter(!is.na({{ by_9 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_9 }}) 
  
  # Union de tabulados 
  tab_final <- bind_rows(tab_nac,tab_area, 
                         tab_reg, tab_prov, 
                         tab_parr, tab_sex, 
                         tab_etnia, tab_quintil,
                         tab_pobreza, tab_pobreza_nbi)
}

tab_full <- map(c("dcronica_2", "dglobal_2", "daguda_2", "dcronica", 
                  "dglobal", "daguda", "dcronica2_5", "dglobal2_5", 
                  "daguda2_5", "sp5", "ob5", "spob5", "malnutricion", 
                  "malnutricion_dc"),
                ~tab_fun(.x, design = survey_design,
                         area, region, prov, parr_pri, f1_s1_2, etnia, 
                         quintil, pobreza, nbi_1))

#==============================================================================#
####               Extraccion de elementos de objetos listas                #### 
#==============================================================================#

# Desnutricion cronica para menores de 2 anios  
tab_dcronica_2 <- tab_full %>%
  pluck(1) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion global para menores de 2 anios  
tab_dglobal_2 <- tab_full %>% 
  pluck(2) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion aguda para menores de 2 anios  
tab_daguda_2 <- tab_full %>% 
  pluck(3) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion cronica para menores de 5 anios  
tab_dcronica <- tab_full %>% 
  pluck(4) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion global para menores de 5 anios  
tab_dglobal <- tab_full %>% 
  pluck(5) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion aguda para menores de 5 anios  
tab_daguda <- tab_full %>% 
  pluck(6) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion cronica para ninios de 2 a 5 anios  
tab_dcronica2_5 <- tab_full %>% 
  pluck(7) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion global para ninios de 2 a 5 anios  
tab_dglobal2_5 <- tab_full %>% 
  pluck(8) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Desnutricion aguda para ninios de 2 a 5 anios   
tab_daguda2_5 <- tab_full %>% 
  pluck(9) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Sobrepeso para menores de 5 anios
tab_sp5 <- tab_full %>% 
  pluck(10) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Obesidad para menores de 5 anios
tab_ob5 <- tab_full %>% 
  pluck(11) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Sobrepeso y obesidad para menores de 5 anios
tab_spob5 <- tab_full %>% 
  pluck(12) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Malnutricion para menores de 5 anios
tab_malnutricion <- tab_full %>% 
  pluck(13) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Malnutricion para menores de 5 anios doble carga
tab_malnutricion_dc <- tab_full %>% 
  pluck(14) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

#==============================================================================#
####                                Excel                                   ####
#==============================================================================#

# Cargar libro
# En este apartado se debe cargar el archivo excel que se creo en el script
# "00_inidice_excel.R" 
# Ej: wb <- loadWorkbook("C:/ENDI/Exports/Tabulados_ENDI_R1.xlsx")

# wb <- loadWorkbook("")
wb <- loadWorkbook("/Tabulados_ENDI_R1.xlsx")

# Funciones -------------------------------------------------------------------#

Style_tab <- function(x, z) {
  
  # Hipervinculo
  headSty <- createStyle(fontSize = 9.5,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = x,
           style      = headSty,
           rows       = 2,
           cols       = 11,
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               x,
               startRow = 2,
               startCol = 11,
               x = makeHyperlinkString(
                 sheet = "INDICE", row = 1, col = 1,
                 text = "Índice"
               )
  )
  
  # Encabezado de la tabla descriptiva 
  headSty <- createStyle(fgFill         = "#836FFF", # color celdas
                         fontColour     = "#363636", # color de la letra
                         fontSize       = 10.5, # tamanio de letra
                         fontName       = "Century Gothic", #fuente
                         halign         = "center", 
                         valign         = "center",
                         border         = "TopBottomLeftRight",
                         borderColour   = "#104E8B", # color filos
                         textDecoration = "bold",
                         wrapText = T
  ) 
  
  df <- data.frame(matrix(ncol = 10, nrow = 0))
  colnames(df) <- c("Desagregación", "", "Indicador", "Error     Estándar",
                    "Límite     Inferior", "Límite Superior",
                    "Coeficiente de Variación", "Efecto de Diseño", 
                    "Numerador Muestral", "Denominador Muestral")
  
  writeData(wb,
            sheet       = x,
            x           = df,
            xy          = c("B", 8),
            colNames    = TRUE,
            headerStyle = headSty,
  )
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 2, 
               widths = 17.5
  ) 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 3, 
               widths = 26.5
  ) 
  
  mergeCells(wb,
             sheet = x,
             cols = 2:3,
             rows = 8
  )
  
  # Desagregacion 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 4:7, 
               widths = 11.50
  ) 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 8, 
               widths = 15.50
  ) 

  # Coeficiente de Variacion 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 9, 
               widths = 11.50
  ) 

  # Efecto de disenio 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 10:11, 
               widths = 15.00
  ) 

  # Tabla descriptiva de resultados
  writeData(wb,
            sheet       = x, 
            x           = z,
            xy          = c("C", 9),
            colNames    = F
  )
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        numFmt         = "0.0" 
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 9:55,
           cols       = 4:9,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "left",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 9:55,
           cols       = 3,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        numFmt         = "#,##0"
  )
  
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 9:55,
           cols       = 10:11,
           gridExpand = TRUE
  )

  # Especificacion de desagregacion 
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "center",
                        valign         = "center",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        wrapText = T
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 9:55,
           cols       = 2:3,
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x,
            x           = "Nacional*",
            xy          = c("B", 9)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 9,
             cols = 2:3 
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Área",
            xy          = c("B", 10)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 10:11,
             cols = 2
  )

  writeData(wb,
            sheet       = x, 
            x           = "Región Natural",
            xy          = c("B", 12)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 12:14,
             cols = 2  
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Provincia",
            xy          = c("B", 15)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 15:37,
             cols = 2  
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Parroquias",
            xy          = c("B", 38)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 38:39,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Sexo",
            xy          = c("B", 40)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 40:41,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Auto-Identificación Étnica",
            xy          = c("B", 42)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 42:46,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Afroecuatoriana/o**",
            xy          = c("C", 43)
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Quintiles",
            xy          = c("B", 47)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 47:51,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Pobreza por Ingresos",
            xy          = c("B", 52)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 52:53,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Pobreza por NBI",
            xy          = c("B", 54)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 54:55,
             cols = 2
  )
  
  # Formato condicional
  # Coeficiente de variacion mayor a 15%
  posStyle <- createStyle(fontColour = "#006100",
                          bgFill     = "#C6EFCE"
  )
  
  conditionalFormatting(wb,
                        sheet = x,
                        rows  = 9:55,
                        cols  = "D",
                        rule  = "H9:H55 > 15",
                        style = posStyle
  )

  # Tamanio de muestra menor a 100 unidades 
  posStyle <- createStyle(fontColour = "#FF3232")
  
  conditionalFormatting(wb,
                        sheet = x,
                        rows  = 9:55,
                        cols  = "D",
                        rule  = "K9:K55 < 100",
                        style = posStyle
  )

  # Figura 
  cir <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#C6EFCE", color = "#C6EFCE") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 57),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 57,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  
  writeData(wb,
            sheet       = x, 
            x           = "     Coeficiente de variación superior al 15%, por tanto se debe utilizar con precaución",
            xy          = c("B", 57)
  )
  
  # Figura 
  cir_1 <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#FF3232", color = "#FF3232") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir_1) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 58),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 58,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "     Estimación poco precisa",
            xy          = c("B", 58)
  )
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 59,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "*   Estimación continental (No incluye Galápagos)",
            xy          = c("B", 59)
  )
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 60,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "** En esta categoría se encuentan también contemplados afrodescendientes, negras/os, mulatas/os",
            xy          = c("B", 60)
  )
  
}

#------------------------------------------------------------------------------#

# Aplicacion de la funcion para la obtencion de tabulados
Style_tab("T2_i1", tab_dcronica_2)
Style_tab("T2_i2", tab_dglobal_2)
Style_tab("T2_i3", tab_daguda_2)
Style_tab("T2_i4", tab_dcronica)
Style_tab("T2_i5", tab_dglobal)
Style_tab("T2_i6", tab_daguda)
Style_tab("T2_i7", tab_dcronica2_5)
Style_tab("T2_i8", tab_dglobal2_5)
Style_tab("T2_i9", tab_daguda2_5)
Style_tab("T2_i10", tab_sp5)
Style_tab("T2_i11", tab_ob5)
Style_tab("T2_i12", tab_spob5)
Style_tab("T2_i13", tab_malnutricion)
Style_tab("T2_i14", tab_malnutricion_dc)

# Abrir archivo sin guardar 
# openXL(wb)

# Apartado para guadar resultados 
# Ej: saveWorkbook(wb, "Exports/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)

saveWorkbook(wb, "/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)
