
# Titulo de la Sintaxis: 
# Exportacion de datos de la calidad de agua 

# Operacion Estadistica: 
# Encuesta Nacional sobre Desnutricion Infantil - ENDI 2022 - 2023 

# Autor de la Sintaxis:
# Instituto Nacional de Estadistica y Censos (INEC)
# Direccion Tecnica: 
# Direccion de Estadisticas Sociodemograficas (DIES) 
# Gestion Interna: 
# Gestion de Estadisticas Permanentes a Hogares (GEPH) 

# Fecha de elaboracion: 29/08/2023
# Fecha de actualizacion: 29/08/2023

# Version: 1.0
# Software: R 4.2.0 

#==============================================================================#
####                   Instalacion y carga de paquetes                      ####
#==============================================================================#

if(!require("pacman")) install.packages("pacman") 
pacman::p_load(here,
               grid, # Para graficas
               ggforce) # Para graficas

#==============================================================================#
####                          Ejecucion de script                           ####
#==============================================================================#

# Indicaciones:

# 1. Se proporciona la ruta de archivo absoluta o completa en la funcion source 
# entre comilla. 
# 2. Use barras diagonales ( / ). Este no es el valor predeterminado para las 
# rutas de archivos de Windows 

# Ejemplo:
# source("C:/ENDI/Scripts/Indicadores/12_calidad_agua.R")

source("/12_calidad_agua.R")

#==============================================================================#
####                                Funciones                               ####
#==============================================================================#

# Para resultados en clasificacion 
tab_fun <- function(design, x, by_1) {  
  
  # Nacional 
  tab_nac <- design %>% 
    srvyr_freq(.data[[x]])
  
  # Area 
  tab_area <- design %>% 
    srvyr_freq_by(.data[[x]], {{ by_1 }}) 

  # Union de tabulados 
  tab_final <- bind_rows(tab_nac, tab_area)
}

tab_full <- map(c("ecoli_f","ecoli_v","cloro_f","cloro_v"),
                ~tab_fun(.x, design = survey_design,
                         area))%>%
  map_if(~ all(c("area") %in% colnames(.)), 
         ~ unite(.x, "Desag_fin",area, sep = "_", remove = FALSE, na.rm = TRUE)) 

# Para resultados en proporcion
tab_fun_1 <- function(design, x, by_1, by_2, by_3, by_4, by_5, by_6, by_7) {  
  
  # Nacional 
  tab_nac <- design %>% 
    srvyr_prop(.data[[x]])
  
  # Area 
  tab_area <- design %>% 
    srvyr_prop_by(.data[[x]], {{ by_1 }}) 
  
  # Region
  tab_reg <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_2}})
  
  # Provincia
  tab_prov <- design %>%
    srvyr_prop_by(.data[[x]], {{ by_3 }})
  
  # Parroquias priorizadas  
  tab_parr <- design %>%
    filter(!is.na({{ by_4 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_4 }}) 
  
  # Quintiles
  tab_quintil <- design %>%
    filter(!is.na({{ by_5 }})) %>% 
    srvyr_prop_by(.data[[x]], {{ by_5 }})
  
  # Pobreza por Ingresos  
  tab_pobreza <- design %>%
    filter(!is.na({{ by_6 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_6 }}) 
  
  # Pobreza por NBI  
  tab_pobreza_nbi <- design %>%
    filter(!is.na({{ by_7 }})) %>%
    srvyr_prop_by(.data[[x]], {{ by_7 }}) 
  
  # Union de tabulados 
  tab_final <- bind_rows(tab_nac, 
                         tab_area, tab_reg,
                         tab_prov, tab_parr,
                         tab_quintil, tab_pobreza,
                         tab_pobreza_nbi)
}

tab_full_1 <- map(c("ecoli_f_new", "ecoli_v_new",
                    "cloro_f_new", "cloro_v_new"),
                  ~tab_fun_1(.x, design = survey_design, 
                             area, region, prov, parr_pri, 
                             quintil, pobreza, nbi_1)) 

#==============================================================================#
####               Extraccion de elementos de objetos listas                #### 
#==============================================================================#

# E-coli fuente
tab_ecoli_f <- tab_full %>% 
  pluck(1) %>%
  select(Desag_fin, ecoli_f, Props, EE, LI, LS, CV, Deff, n) %>% 
  mutate(ecoli_f = as.character(ecoli_f))%>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-c(Desag_fin, ecoli_f), as.numeric))

# E-coli vaso
tab_ecoli_v <- tab_full %>% 
  pluck(2) %>%
  select(Desag_fin,ecoli_v,Props, EE, LI, LS, CV, Deff, n) %>% 
  mutate(ecoli_v = as.character(ecoli_v))%>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-c(Desag_fin, ecoli_v), as.numeric))

# Cloro fuente
tab_cloro_f <- tab_full %>% 
  pluck(3) %>%
  select(Desag_fin,cloro_f,Props, EE, LI, LS, CV, Deff, n) %>% 
  mutate(cloro_f = as.character(cloro_f))%>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-c(Desag_fin, cloro_f), as.numeric))

# Cloro vaso
tab_cloro_v <- tab_full %>% 
  pluck(4) %>%
  select(Desag_fin,cloro_v,Props, EE, LI, LS, CV, Deff, n) %>% 
  mutate(cloro_v = as.character(cloro_v))%>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-c(Desag_fin, cloro_v), as.numeric))

# E-coli fuente
tab_ecoli_f_new_1 <- tab_full_1 %>% 
  pluck(1) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# E-coli vaso
tab_ecoli_v_new_1 <- tab_full_1 %>% 
  pluck(2) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Cloro fuente
tab_cloro_f_new_1 <- tab_full_1 %>% 
  pluck(3) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

# Cloro vaso
tab_cloro_v_new_1 <- tab_full_1 %>% 
  pluck(4) %>%
  mutate_all(.funs = ~ifelse(is.na(.), "", .)) %>% 
  mutate(across(-Desag, as.numeric))

#==============================================================================#
####                                Excel                                   ####
#==============================================================================#

# Cargar libro
# En este apartado se debe cargar el archivo excel que se creo en el script
# "00_inidice_excel.R" 
# Ej: wb <- loadWorkbook("C:/ENDI/Exports/Tabulados_ENDI_R1.xlsx")

# wb <- loadWorkbook("")
wb <- loadWorkbook("/Tabulados_ENDI_R1.xlsx")

# Funciones -------------------------------------------------------------------#

Style_tab_freq <- function(x, z) {
  
  # Hipervinculo
  headSty <- createStyle(fontSize = 9.5,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = x,
           style      = headSty,
           rows       = 2,
           cols       = 11,
           gridExpand = TRUE
  )
  
  
  writeFormula(wb, x,
               startRow = 2,
               startCol = 11,
               x = makeHyperlinkString(
                 sheet = "INDICE", row = 1, col = 1,
                 text = "Índice"
               )
  )
  
  # Encabezado de la tabla descriptiva 
  headSty <- createStyle(fgFill         = "#836FFF", # color celdas
                         fontColour     = "#363636", # color de fuente
                         fontSize       = 10.5, # tamanio de letra
                         fontName       = "Century Gothic", #fuente
                         halign         = "center", 
                         valign         = "center",
                         border         = "TopBottomLeftRight",
                         borderColour   = "#104E8B", # color filos
                         textDecoration = "bold",
                         wrapText = T
  ) 
  
  
  df <- data.frame(matrix(ncol = 10, nrow = 0))
  colnames(df) <- c("Desagregación", "", "Clasificación", 
                    "Indicador", "Error     Estándar",
                    "Límite     Inferior", "Límite Superior",
                    "Coeficiente de Variación", "Efecto de Diseño", 
                    "Tamaño de la Muestra")
  
  writeData(wb,
            sheet       = x,
            x           = df,
            xy          = c("B", 9),
            colNames    = TRUE,
            headerStyle = headSty,
  )
  
  mergeCells(wb,
             sheet = x,
             cols = 2:3,
             rows = 9
  ) 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 2:3, 
               widths = 16.50
  )# Desagregacion  
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 4, 
               widths = 15.50
  ) # Clasificacion de Anemia 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 5:8, 
               widths = 11.50
  )
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 9, 
               widths = 15.50
  ) # Coeficiente de Variacion  
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 10, 
               widths = 11.50
  ) # Efecto de disenio 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 11, 
               widths = 15.00
  ) # Tamanio de muestra  
  
  # Tabla descriptiva de resultados 
  writeData(wb,
            sheet       = x, 
            x           = z,
            xy          = c("C", 10),
            colNames    = F
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # blue violet
                        numFmt         = "0.0" 
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:21,
           cols       = 5:10,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "left",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # blue violet
  )
  
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:21,
           cols       = 2:4,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra 
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # blue violet
                        numFmt         = "#,##0"
  )
  
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:21,
           cols       = 11,
           gridExpand = TRUE
  )
  
  # Especificacion de desagregacion 
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "center",
                        valign         = "center",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        wrapText = T
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:21,
           cols       = 2:3,
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Nacional*",
            xy          = c("B", 10)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 10:13,
             cols = 2:3 
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Área",
            xy          = c("B", 14)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 14:21,
             cols = 2 
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 14:17,
             cols = 3 
  )
  
  mergeCells(wb, 
             sheet= x,
             rows = 18:21,
             cols = 3 
  )
  
  # Formato condicional
  # Coeficiente de variacion mayor a 15%
  posStyle <- createStyle(fontColour = "#006100",
                          bgFill     = "#C6EFCE"
  )
  
  conditionalFormatting(wb,
                        sheet = x,
                        rows  = 10:21,
                        cols  = "E",
                        rule  = "I10:I21 > 15",
                        style = posStyle
  )
  
  # Tamanio de muestra menor a 100 unidades 
  posStyle <- createStyle(fontColour = "#FF3232")
  
  conditionalFormatting(wb,
                        sheet =x,
                        rows  = 10:21,
                        cols  = "E",
                        rule  = "K10:K21 < 100",
                        style = posStyle
  )
  
  # Figura 
  cir <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#C6EFCE", color = "#C6EFCE") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 23),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 23,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  
  writeData(wb,
            sheet       = x, 
            x           = "     Coeficiente de variación superior al 15%, por tanto se debe utilizar con precaución",
            xy          = c("B", 23)
  )
  
  # Figura 
  cir_1 <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#FF3232", color = "#FF3232") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir_1) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 24),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 24,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  
  writeData(wb,
            sheet       = x, 
            x           = "     Estimación poco precisa",
            xy          = c("B", 24)
  )
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 25,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "*   Estimación continental (No incluye Galápagos)",
            xy          = c("B", 25)
  )
  
}

Style_tab_prop <- function(x, z) {
  
  # Hipervinculo
  headSty <- createStyle(fontSize = 9.5,
                         fontName = "Century Gothic",
                         halign = "center")
  
  addStyle(wb,
           sheet      = x,
           style      = headSty,
           rows       = 2,
           cols       = 11,
           gridExpand = TRUE
  )
  
  writeFormula(wb, 
               x,
               startRow = 2,
               startCol = 11,
               x = makeHyperlinkString(
                 sheet = "INDICE", row = 1, col = 1,
                 text = "Índice"
               )
  )
  
  # Encabezado de la tabla descriptiva 
  headSty <- createStyle(fgFill         = "#836FFF", # color celdas
                         fontColour     = "#363636", # color de fuente
                         fontSize       = 10.5, # tamanio de letra
                         fontName       = "Century Gothic", #fuente
                         halign         = "center", 
                         valign         = "center",
                         border         = "TopBottomLeftRight",
                         borderColour   = "#104E8B", # color filos
                         textDecoration = "bold",
                         wrapText = T
  ) 
  
  df <- data.frame(matrix(ncol = 10, nrow = 0))
  colnames(df) <- c("Desagregación", "", "Indicador", "Error     Estándar",
                    "Límite     Inferior", "Límite Superior",
                    "Coeficiente de Variación", "Efecto de Diseño", 
                    "Numerador Muestral", "Denominador Muestral")
  
  writeData(wb,
            sheet       = x,
            x           = df,
            xy          = c("B", 9),
            colNames    = TRUE,
            headerStyle = headSty,
  )
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 2, 
               widths = 17.5
  ) 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 3, 
               widths = 26.5
  ) 
  
  mergeCells(wb,
             sheet = x,
             cols = 2:3,
             rows = 9
  )
  
  # Desagregacion 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 4:7, 
               widths = 11.50
  ) 
  
  setColWidths(wb, 
               sheet  = x, 
               cols   = 8, 
               widths = 15.50
  ) 
  
  # Coeficiente de Variacion 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 9, 
               widths = 11.50
  ) 
  
  # Efecto de disenio 
  setColWidths(wb, 
               sheet  = x, 
               cols   = 10:11, 
               widths = 15.00
  ) 
  
  # Tabla descriptiva de resultados
  writeData(wb,
            sheet       = x, 
            x           = z,
            xy          = c("C", 10),
            colNames    = F
  )
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        numFmt         = "0.0" 
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:49,
           cols       = 4:9,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "left",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:49,
           cols       = 3,
           gridExpand = TRUE
  )
  
  
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", # fuente
                        halign         = "right",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        numFmt         = "#,##0"
  )
  
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:49,
           cols       = 10:11,
           gridExpand = TRUE
  )
  
  # Especificacion de desagregacion 
  tabSty <- createStyle(fontSize       = 10.5, # tamanio de letra
                        fontName       = "Century Gothic", #fuente
                        halign         = "center",
                        valign         = "center",
                        border         = "TopBottomLeftRight",
                        borderColour   = "#104E8B", # color filos
                        wrapText = T
  )
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 10:49,
           cols       = 2:3,
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x,
            x           = "Nacional*",
            xy          = c("B", 10)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 10,
             cols = 2:3 
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Área",
            xy          = c("B", 11)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 11:12,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Región Natural",
            xy          = c("B", 13)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 13:15,
             cols = 2 
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Provincia",
            xy          = c("B", 16)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 16:38,
             cols = 2 
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Parroquias",
            xy          = c("B", 39)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 39:40,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Quintiles",
            xy          = c("B", 41)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 41:45,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Pobreza por Ingresos",
            xy          = c("B", 46)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 46:47,
             cols = 2
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "Pobreza por NBI",
            xy          = c("B", 48)
  )
  
  mergeCells(wb, 
             sheet = x,
             rows = 48:49,
             cols = 2
  )
  
  # Formato condicional
  # Coeficiente de variacion mayor a 15%
  posStyle <- createStyle(fontColour = "#006100",
                          bgFill     = "#C6EFCE"
  )
  
  conditionalFormatting(wb,
                        sheet = x,
                        rows  = 10:49,
                        cols  = "D",
                        rule  = "H10:H49 > 15",
                        style = posStyle
  )
  
  # Tamanio de muestra menor a 100 unidades 
  posStyle <- createStyle(fontColour = "#FF3232")
  
  conditionalFormatting(wb,
                        sheet = x,
                        rows  = 10:49,
                        cols  = "D",
                        rule  = "K10:K49 < 100",
                        style = posStyle
  )
  
  # Figura 
  cir <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#C6EFCE", color = "#C6EFCE") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 51),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 51,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  
  writeData(wb,
            sheet       = x, 
            x           = "     Coeficiente de variación superior al 15%, por tanto se debe utilizar con precaución",
            xy          = c("B", 51)
  )
  
  # Figura 
  cir_1 <- ggplot() +
    coord_fixed(ratio = 1) +
    geom_circle(aes(x0 = 1, y0 = 1, r = 1),
                fill = "#FF3232", color = "#FF3232") +
    labs(x = NULL, y = NULL) +
    theme(axis.ticks = element_blank(),
          axis.text = element_blank(),
          axis.ticks.length = unit(0, "pt"),
          axis.title = element_blank(),
          plot.background = element_blank(),
          plot.margin = grid::unit(c(0,0,0,0),"cm"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.background = element_blank())
  
  print(cir_1) 
  
  insertPlot(wb, 
             x,
             xy = c("B", 52),
             width = 0.15, 
             height = 0.15, 
             fileType = "png", 
             units = "in")
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 52,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "     Estimación poco precisa",
            xy          = c("B", 52)
  )
  
  # Notas 
  tabSty <- createStyle(fontSize = 9,
                        fontName = "Century Gothic")
  
  addStyle(wb,
           sheet      = x,
           style      = tabSty,
           rows       = 53,
           cols       = "B",  
           gridExpand = TRUE
  )
  
  writeData(wb,
            sheet       = x, 
            x           = "*   Estimación continental (No incluye Galápagos)",
            xy          = c("B", 53)
  )

}

#------------------------------------------------------------------------------#

# Aplicacion de la funcion para la obtencion de tabulados
Style_tab_prop("T9_i1", tab_cloro_f_new_1)
Style_tab_prop("T9_i2", tab_cloro_v_new_1)
Style_tab_prop("T9_i3", tab_ecoli_f_new_1)
Style_tab_prop("T9_i4", tab_ecoli_v_new_1)
Style_tab_freq("T9_i5", tab_cloro_f)
Style_tab_freq("T9_i6", tab_cloro_v)
Style_tab_freq("T9_i7", tab_ecoli_f)
Style_tab_freq("T9_i8", tab_ecoli_v)

# Abrir archivo sin guardar 
# openXL(wb)

# Apartado para guadar resultados 
# Ej: saveWorkbook(wb, "Exports/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)

saveWorkbook(wb, "/Tabulados_ENDI_R1.xlsx", overwrite = TRUE)
